@@ -1,7 +1,7 @@
 /* pam_password.c - PAM Password Management */
 
 /*
- * $Id: pam_password.c,v 1.4 2006/01/12 10:06:49 t8m Exp $
+ * $Id: pam_password.c,v 1.5 2006/07/24 15:47:40 kukuk Exp $
  */
 
 /* #define DEBUG */
@@ -52,7 +52,7 @@ int pam_chauthtok(pam_handle_t *pamh, int flags)
 	D(("will resume when ready", retval));
     }
 
-#if HAVE_LIBAUDIT
+#ifdef HAVE_LIBAUDIT
     retval = _pam_auditlog(pamh, PAM_CHAUTHTOK, retval, flags);
 #endif
 
